<header class="nice-padding hasform">
	<div class="row">
		<div class="left">
			<div class="col">
				{% block h1 %}<h1 {% if chooser.header_icon %}class="icon icon-{{ chooser.header_icon }}"{% endif %}>Choose <span>{{ opts.verbose_name }}</span></h1>{% endblock %}
			</div>
		</div>
	</div>
</header>

<div class="nice-padding">
	{# Need to keep the form in the HTML, even if the snippet is not searchable #}
	{# This is to allow pagination links to be generated from the form action URL #}
	{% block search_form %}
	{% if is_searchable %}
	<form class="search-bar" action="{{ chooser_url }}" method="GET">
		{% block search_fields %}
		<ul class="fields">
			<li>
				<div class="field-content">
					<div class="input">
						<input type="text" name="q" id="id_q" placeholder="Search" autocomplete="off">
					</div>
				</div>
			</li>
		</ul>
		{% endblock %}
	</form>
	{% endif %}
	{% endblock %}

	<div id="search-results" class="listing snippets">
		{% block search_results %}
		{% include results_template_name %}
		{% endblock %}
	</div>
</div>
