{% load wagtailadmin_tags %}

<div class="row">
	<div class="result-list">
		{% if not object_list %}
			{% block no_matches %}
			{% if is_searching %}
				<p>No {{ opts.verbose_name_plural }} found matching your search.</p>
			{% else %}
				<p>There are no {{ opts.verbose_name_plural }}.</p>
			{% endif %}
			{% endblock %}
		{% else %}
			<table class="listing">
				<thead>
					{% block table_header %}
					<tr class="table-headers">
						<th>Title</th>
						{% block extra_table_headers %}
						{% endblock %}
					</tr>
					{% endblock %}
				</thead>
				<tbody>
					{% for instance in object_list %}
						{% block table_row %}
						<tr>
							<td class="title">
								<h2><a class="model-choice" data-pk="{{ instance.pk }}" href="#">
									{{ instance }}
								</a></h2>
							</td>
							{% block extra_table_row_columns %}
							{% endblock %}
						</tr>
						{% endblock %}
					{% endfor %}
				</tbody>
			</table>
		{% endif %}
	</div>

	{% paginate page %}
</div>
